@@ -1,10 +1,10 @@
 from fastapi import APIRouter
 from fastapi import FastAPI
-import uvicorn
 
+from compass.api.plugins import redis
 from compass.api.routes import authentication
 from compass.api.routes import members
-from compass.api.utility import redis_handler
+
 
 open_api_tag_metadata = [
     {
@@ -34,13 +34,13 @@ and is licensed under the **[MIT license](https://choosealicense.com/licenses/mi
 app = FastAPI(
     title="Compass Interface — the unofficial Compass API",
     description=long_description,
-    version="0.22.2",
-    on_shutdown=[redis_handler.on_shutdown],
+    version="0.22.7",
     openapi_tags=open_api_tag_metadata,
 )
+app.router.lifespan_context = redis.lifetime
 
+# V1 Routing
 version_one = APIRouter()
-
 version_one.include_router(
     members.router,
     prefix="/members",
@@ -55,18 +55,13 @@ version_one.include_router(
     responses={404: {"description": "Not found!"}},
 )
 
+# Overall app routing
 app.include_router(
     version_one,
     prefix="/v1",
     dependencies=[],
 )
 
-
-@app.on_event("startup")
-async def on_startup() -> None:
-    await redis_handler.on_startup(app)
-
-
 # Appointments report - role details (except M01Ex, M04), ongoing details (except M01Ex imputing), disclosures
 # Member Directory - emergency contact details
 # Permit Report - permits
@@ -75,15 +70,15 @@ async def on_startup() -> None:
 
 # base = api.compass.cys.org.uk
 # /v1/
-#    /members/me
-#    /members/{memberNumber}
+#    /members/me ✔
+#    /members/{memberNumber} ✔
 #            /XXX/ - default is profile ✔
-#                /roles ✔
-#                /ongoing-training ✔
-#                /disclosures
-#                /training
-#                /permits
-#                /awards
+#                /roles ✘
+#                /permits ✔
+#                /training ✔
+#                /ongoing-learning ✔
+#                /awards ✔
+#                /disclosures ✔
 #                /emergency_details          ??
 #                /communication_preferences  ??
 #                /visibility                 ??
@@ -105,7 +100,12 @@ async def on_startup() -> None:
 
 
 if __name__ == "__main__":
-    uvicorn.run("app:app", host="0.0.0.0", port=8000)
+    import uvicorn
+
+    from compass.core.logger import enable_debug_logging
+
+    enable_debug_logging()
+    uvicorn.run("app:app", host="0.0.0.0", port=8002)
     print()
 
 
